'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function (liveId, cookie) {
  return new Promise(function (resolve, reject) {
    (0, _getPlayerStatus2.default)(liveId, cookie).then(function (playerStatus) {
      var port = playerStatus.port,
          addr = playerStatus.addr,
          thread = playerStatus.thread,
          version = playerStatus.version,
          res_from = playerStatus.res_from,
          user_id = playerStatus.user_id,
          premium = playerStatus.premium,
          mail = playerStatus.mail;

      var viewer = _net2.default.connect(port, addr);

      viewer.on('connect', function () {
        var comment = (0, _cheerio2.default)('<thread />');
        comment.attr({ thread: thread, version: version, res_from: res_from });
        comment.options.xmlMode = 'on';
        viewer.write(comment.toString() + '\0');
        viewer.setEncoding('utf-8');
      });

      viewer.on('data', function (buffer) {
        var chunk = buffer.toString();
        if (!chunk.match(/\0$/)) return;
        var data = (0, _cheerio2.default)('<data>' + chunk + '</data>');

        var resultCodeValue = data.find('thread').attr('resultcode');
        if (resultCodeValue) {
          var foundThread = data.find('thread');
          var ticket = foundThread.attr('ticket');
          playerStatus.last_res = foundThread.attr('last_res');
          var attrs = { thread: thread, ticket: ticket, mail: mail, user_id: user_id, premium: premium };
          if (resultCodeValue === '0') {
            viewer.emit('handshaked', attrs, playerStatus);
          } else {
            viewer.emit('error', foundThread.toString());
          }
        }

        var comments = data.find('chat');
        for (var i = 0, len = comments.length; i < len; i++) {
          var element = (0, _cheerio2.default)(comments[i]);
          var comment = {
            attr: element.attr(),
            text: element.text(),
            usericon: 'http://uni.res.nimg.jp/img/user/thumb/blank.jpg'
          };
          var _comment$attr = comment.attr,
              anonymity = _comment$attr.anonymity,
              _user_id = _comment$attr.user_id;

          if (!anonymity && _user_id) comment.usericon = 'http://usericon.nimg.jp/usericon/' + _user_id.slice(0, 2) + '/' + _user_id + '.jpg';
          viewer.emit('comment', comment);
          if (comment.attr.no > playerStatus.comment_count) playerStatus.last_res = comment.attr.no;
        }
      });

      resolve(viewer);
    }).catch(function (err) {
      return reject(err);
    });
  });
};

var _net = require('net');

var _net2 = _interopRequireDefault(_net);

var _cheerio = require('cheerio');

var _cheerio2 = _interopRequireDefault(_cheerio);

var _getPlayerStatus = require('./getPlayerStatus');

var _getPlayerStatus2 = _interopRequireDefault(_getPlayerStatus);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }